@@ -10,7 +10,6 @@ from ..test_verbosity import insert_logging_mock
 
 def insert_execute_command_mock(
     command,
-    input_file=module.DO_NOT_CAPTURE,
     working_directory=None,
     borg_exit_codes=None,
 ):
@@ -20,7 +19,6 @@ def insert_execute_command_mock(
     )
     flexmock(module).should_receive('execute_command').with_args(
         command,
-        input_file=input_file,
         output_log_level=module.logging.INFO,
         environment=None,
         working_directory=working_directory,
@@ -33,7 +31,7 @@ def test_import_key_calls_borg_with_required_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', 'repo'))
+    insert_execute_command_mock(('borg', 'key', 'import', '--log-json', 'repo', '-'))
 
     module.import_key(
         repository_path='repo',
@@ -48,7 +46,7 @@ def test_import_key_calls_borg_with_local_path():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg1', 'key', 'import', 'repo'))
+    insert_execute_command_mock(('borg1', 'key', 'import', '--log-json', 'repo', '-'))
 
     module.import_key(
         repository_path='repo',
@@ -65,7 +63,9 @@ def test_import_key_calls_borg_using_exit_codes():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
     borg_exit_codes = flexmock()
-    insert_execute_command_mock(('borg', 'key', 'import', 'repo'), borg_exit_codes=borg_exit_codes)
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--log-json', 'repo', '-'), borg_exit_codes=borg_exit_codes
+    )
 
     module.import_key(
         repository_path='repo',
@@ -80,7 +80,9 @@ def test_import_key_calls_borg_with_remote_path_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--remote-path', 'borg1', 'repo'))
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--remote-path', 'borg1', '--log-json', 'repo', '-')
+    )
 
     module.import_key(
         repository_path='repo',
@@ -96,7 +98,9 @@ def test_import_key_calls_borg_with_umask_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--umask', '0770', 'repo'))
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--umask', '0770', '--log-json', 'repo', '-')
+    )
 
     module.import_key(
         repository_path='repo',
@@ -107,26 +111,13 @@ def test_import_key_calls_borg_with_umask_flags():
     )
 
 
-def test_import_key_calls_borg_with_log_json_flags():
-    flexmock(module.flags).should_receive('make_flags').and_return(())
-    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
-    flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--log-json', 'repo'))
-
-    module.import_key(
-        repository_path='repo',
-        config={'log_json': True},
-        local_borg_version='1.2.3',
-        import_arguments=flexmock(paper=False, path=None),
-        global_arguments=flexmock(dry_run=False),
-    )
-
-
 def test_import_key_calls_borg_with_lock_wait_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--lock-wait', '5', 'repo'))
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--log-json', '--lock-wait', '5', 'repo', '-')
+    )
 
     module.import_key(
         repository_path='repo',
@@ -141,7 +132,9 @@ def test_import_key_calls_borg_with_extra_borg_options():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--extra', 'value with space', 'repo'))
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--log-json', '--extra', 'value with space', 'repo', '-')
+    )
 
     module.import_key(
         repository_path='repo',
@@ -156,7 +149,7 @@ def test_import_key_with_log_info_calls_borg_with_info_parameter():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--info', 'repo'))
+    insert_execute_command_mock(('borg', 'key', 'import', '--log-json', '--info', 'repo', '-'))
     insert_logging_mock(logging.INFO)
 
     module.import_key(
@@ -172,7 +165,9 @@ def test_import_key_with_log_debug_calls_borg_with_debug_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--debug', '--show-rc', 'repo'))
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--log-json', '--debug', '--show-rc', 'repo', '-')
+    )
     insert_logging_mock(logging.DEBUG)
 
     module.import_key(
@@ -188,7 +183,7 @@ def test_import_key_calls_borg_with_paper_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(('--paper',))
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', '--paper', 'repo'))
+    insert_execute_command_mock(('borg', 'key', 'import', '--log-json', '--paper', 'repo', '-'))
 
     module.import_key(
         repository_path='repo',
@@ -203,7 +198,9 @@ def test_import_key_calls_borg_with_path_argument():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').with_args('source').and_return(True)
-    insert_execute_command_mock(('borg', 'key', 'import', 'repo', 'source'), input_file=None)
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--log-json', 'repo', 'source'),
+    )
 
     module.import_key(
         repository_path='repo',
@@ -234,7 +231,7 @@ def test_import_key_with_stdin_path_calls_borg_without_path_argument():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', 'repo'))
+    insert_execute_command_mock(('borg', 'key', 'import', '--log-json', 'repo', '-'))
 
     module.import_key(
         repository_path='repo',
@@ -264,7 +261,9 @@ def test_import_key_calls_borg_with_working_directory():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     flexmock(module.os.path).should_receive('exists').never()
-    insert_execute_command_mock(('borg', 'key', 'import', 'repo'), working_directory='/working/dir')
+    insert_execute_command_mock(
+        ('borg', 'key', 'import', '--log-json', 'repo', '-'), working_directory='/working/dir'
+    )
 
     module.import_key(
         repository_path='repo',
@@ -282,8 +281,7 @@ def test_import_key_calls_borg_with_path_argument_and_working_directory():
         True,
     ).once()
     insert_execute_command_mock(
-        ('borg', 'key', 'import', 'repo', 'source'),
-        input_file=None,
+        ('borg', 'key', 'import', '--log-json', 'repo', 'source'),
         working_directory='/working/dir',
     )
 
