@@ -28,7 +28,7 @@ def test_make_info_command_constructs_borg_info_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--repo', 'repo')
+    assert command == ('borg', 'info', '--log-json', '--repo', 'repo')
 
 
 def test_make_info_command_with_log_info_passes_through_to_command():
@@ -52,7 +52,7 @@ def test_make_info_command_with_log_info_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--info', '--repo', 'repo')
+    assert command == ('borg', 'info', '--info', '--log-json', '--repo', 'repo')
 
 
 def test_make_info_command_with_log_info_and_json_omits_borg_logging_flags():
@@ -76,7 +76,7 @@ def test_make_info_command_with_log_info_and_json_omits_borg_logging_flags():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--json', '--repo', 'repo')
+    assert command == ('borg', 'info', '--log-json', '--json', '--repo', 'repo')
 
 
 def test_make_info_command_with_log_debug_passes_through_to_command():
@@ -100,7 +100,7 @@ def test_make_info_command_with_log_debug_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--debug', '--show-rc', '--repo', 'repo')
+    assert command == ('borg', 'info', '--debug', '--show-rc', '--log-json', '--repo', 'repo')
 
 
 def test_make_info_command_with_log_debug_and_json_omits_borg_logging_flags():
@@ -123,7 +123,7 @@ def test_make_info_command_with_log_debug_and_json_omits_borg_logging_flags():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--json', '--repo', 'repo')
+    assert command == ('borg', 'info', '--log-json', '--json', '--repo', 'repo')
 
 
 def test_make_info_command_with_json_passes_through_to_command():
@@ -146,7 +146,7 @@ def test_make_info_command_with_json_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--json', '--repo', 'repo')
+    assert command == ('borg', 'info', '--log-json', '--json', '--repo', 'repo')
 
 
 def test_make_info_command_with_archive_uses_match_archives_flags():
@@ -169,7 +169,15 @@ def test_make_info_command_with_archive_uses_match_archives_flags():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--match-archives', 'archive', '--repo', 'repo')
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--match-archives',
+        'archive',
+        '--repo',
+        'repo',
+    )
 
 
 def test_make_info_command_with_local_path_passes_through_to_command():
@@ -192,7 +200,7 @@ def test_make_info_command_with_local_path_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg1', 'info', '--repo', 'repo')
+    assert command == ('borg1', 'info', '--log-json', '--repo', 'repo')
 
 
 def test_make_info_command_with_remote_path_passes_through_to_command():
@@ -219,7 +227,7 @@ def test_make_info_command_with_remote_path_passes_through_to_command():
         remote_path='borg1',
     )
 
-    assert command == ('borg', 'info', '--remote-path', 'borg1', '--repo', 'repo')
+    assert command == ('borg', 'info', '--remote-path', 'borg1', '--log-json', '--repo', 'repo')
 
 
 def test_make_info_command_with_umask_passes_through_to_command():
@@ -244,33 +252,7 @@ def test_make_info_command_with_umask_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--umask', '077', '--repo', 'repo')
-
-
-def test_make_info_command_with_log_json_passes_through_to_command():
-    flexmock(module.flags).should_receive('make_flags').and_return(())
-    flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
-        ('--log-json',),
-    )
-    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        None,
-        None,
-        '2.3.4',
-    ).and_return(())
-    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
-    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
-
-    command = module.make_info_command(
-        repository_path='repo',
-        config={'log_json': True},
-        local_borg_version='2.3.4',
-        global_arguments=flexmock(),
-        info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
-        local_path='borg',
-        remote_path=None,
-    )
-
-    assert command == ('borg', 'info', '--log-json', '--repo', 'repo')
+    assert command == ('borg', 'info', '--umask', '077', '--log-json', '--repo', 'repo')
 
 
 def test_make_info_command_with_lock_wait_passes_through_to_command():
@@ -297,7 +279,39 @@ def test_make_info_command_with_lock_wait_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--lock-wait', '5', '--repo', 'repo')
+    assert command == ('borg', 'info', '--log-json', '--lock-wait', '5', '--repo', 'repo')
+
+
+def test_make_info_command_with_extra_borg_options_passes_through_to_command():
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None,
+        None,
+        '2.3.4',
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    config = {'extra_borg_options': {'info': '--extra "value with space"'}}
+
+    command = module.make_info_command(
+        repository_path='repo',
+        config=config,
+        local_borg_version='2.3.4',
+        global_arguments=flexmock(),
+        info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
+        local_path='borg',
+        remote_path=None,
+    )
+
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--extra',
+        'value with space',
+        '--repo',
+        'repo',
+    )
 
 
 def test_make_info_command_transforms_prefix_into_match_archives_flags():
@@ -324,7 +338,15 @@ def test_make_info_command_transforms_prefix_into_match_archives_flags():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--match-archives', 'sh:foo*', '--repo', 'repo')
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--match-archives',
+        'sh:foo*',
+        '--repo',
+        'repo',
+    )
 
 
 def test_make_info_command_prefers_prefix_over_archive_name_format():
@@ -351,7 +373,15 @@ def test_make_info_command_prefers_prefix_over_archive_name_format():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--match-archives', 'sh:foo*', '--repo', 'repo')
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--match-archives',
+        'sh:foo*',
+        '--repo',
+        'repo',
+    )
 
 
 def test_make_info_command_transforms_archive_name_format_into_match_archives_flags():
@@ -374,7 +404,15 @@ def test_make_info_command_transforms_archive_name_format_into_match_archives_fl
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--match-archives', 'sh:bar-*', '--repo', 'repo')
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--match-archives',
+        'sh:bar-*',
+        '--repo',
+        'repo',
+    )
 
 
 def test_make_info_command_with_match_archives_option_passes_through_to_command():
@@ -401,7 +439,15 @@ def test_make_info_command_with_match_archives_option_passes_through_to_command(
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--match-archives', 'sh:foo-*', '--repo', 'repo')
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--match-archives',
+        'sh:foo-*',
+        '--repo',
+        'repo',
+    )
 
 
 def test_make_info_command_with_match_archives_flag_passes_through_to_command():
@@ -425,7 +471,15 @@ def test_make_info_command_with_match_archives_flag_passes_through_to_command():
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', '--match-archives', 'sh:foo-*', '--repo', 'repo')
+    assert command == (
+        'borg',
+        'info',
+        '--log-json',
+        '--match-archives',
+        'sh:foo-*',
+        '--repo',
+        'repo',
+    )
 
 
 @pytest.mark.parametrize('argument_name', ('sort_by', 'first', 'last'))
@@ -459,7 +513,7 @@ def test_make_info_command_passes_arguments_through_to_command(argument_name):
         remote_path=None,
     )
 
-    assert command == ('borg', 'info', flag_name, 'value', '--repo', 'repo')
+    assert command == ('borg', 'info', '--log-json', flag_name, 'value', '--repo', 'repo')
 
 
 def test_make_info_command_with_date_based_matching_passes_through_to_command():
@@ -497,6 +551,7 @@ def test_make_info_command_with_date_based_matching_passes_through_to_command():
     assert command == (
         'borg',
         'info',
+        '--log-json',
         '--newer',
         '1d',
         '--newest',
@@ -512,10 +567,11 @@ def test_make_info_command_with_date_based_matching_passes_through_to_command():
 
 def test_display_archives_info_calls_two_commands():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module).should_receive('make_info_command')
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
-    flexmock(module).should_receive('execute_command_and_capture_output').once()
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield().once()
     flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags')
     flexmock(module).should_receive('execute_command').once()
 
@@ -530,11 +586,11 @@ def test_display_archives_info_calls_two_commands():
 
 def test_display_archives_info_with_json_calls_json_command_only():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module).should_receive('make_info_command')
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
-    json_output = flexmock()
-    flexmock(module).should_receive('execute_command_and_capture_output').and_return(json_output)
+    flexmock(module).should_receive('execute_command_and_capture_output').and_yield('{}')
     flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags').never()
     flexmock(module).should_receive('execute_command').never()
 
@@ -546,12 +602,13 @@ def test_display_archives_info_with_json_calls_json_command_only():
             global_arguments=flexmock(),
             info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
         )
-        == json_output
+        == '{}'
     )
 
 
 def test_display_archives_info_calls_borg_with_working_directory():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module).should_receive('make_info_command')
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
@@ -563,7 +620,7 @@ def test_display_archives_info_calls_borg_with_working_directory():
         working_directory='/working/dir',
         borg_local_path=object,
         borg_exit_codes=object,
-    ).once()
+    ).and_yield().once()
     flexmock(module.flags).should_receive('warn_for_aggressive_archive_flags')
     flexmock(module).should_receive('execute_command').with_args(
         full_command=object,
