@@ -18,7 +18,7 @@ def test_transfer_archives_calls_borg_with_flags():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -55,7 +55,7 @@ def test_transfer_archives_with_dry_run_calls_borg_with_dry_run_flag():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--repo', 'repo', '--dry-run'),
+        ('borg', 'transfer', '--log-json', '--repo', 'repo', '--dry-run'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -89,7 +89,7 @@ def test_transfer_archives_with_log_info_calls_borg_with_info_flag():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--info', '--repo', 'repo'),
+        ('borg', 'transfer', '--info', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -123,7 +123,7 @@ def test_transfer_archives_with_log_debug_calls_borg_with_debug_flag():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--debug', '--show-rc', '--repo', 'repo'),
+        ('borg', 'transfer', '--debug', '--show-rc', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -162,7 +162,7 @@ def test_transfer_archives_with_archive_calls_borg_with_match_archives_flag():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--match-archives', 'archive', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--match-archives', 'archive', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -200,7 +200,7 @@ def test_transfer_archives_with_match_archives_calls_borg_with_match_archives_fl
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--match-archives', 'sh:foo*', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--match-archives', 'sh:foo*', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -238,7 +238,7 @@ def test_transfer_archives_with_archive_name_format_calls_borg_with_match_archiv
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--match-archives', 'sh:bar-*', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--match-archives', 'sh:bar-*', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -272,7 +272,7 @@ def test_transfer_archives_with_local_path_calls_borg_via_local_path():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg2', 'transfer', '--repo', 'repo'),
+        ('borg2', 'transfer', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -308,7 +308,7 @@ def test_transfer_archives_with_exit_codes_calls_borg_using_them():
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     borg_exit_codes = flexmock()
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -346,7 +346,7 @@ def test_transfer_archives_with_remote_path_calls_borg_with_remote_path_flags():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--remote-path', 'borg2', '--repo', 'repo'),
+        ('borg', 'transfer', '--remote-path', 'borg2', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -383,7 +383,7 @@ def test_transfer_archives_with_umask_calls_borg_with_umask_flags():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--umask', '077', '--repo', 'repo'),
+        ('borg', 'transfer', '--umask', '077', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -407,43 +407,6 @@ def test_transfer_archives_with_umask_calls_borg_with_umask_flags():
     )
 
 
-def test_transfer_archives_with_log_json_calls_borg_with_log_json_flags():
-    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
-    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
-    flexmock(module.flags).should_receive('make_flags').and_return(())
-    flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
-        ('--log-json',),
-    )
-    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
-    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
-    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
-    flexmock(module.environment).should_receive('make_environment')
-    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
-    flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--log-json', '--repo', 'repo'),
-        output_log_level=module.borgmatic.logger.ANSWER,
-        output_file=None,
-        environment=None,
-        working_directory=None,
-        borg_local_path='borg',
-        borg_exit_codes=None,
-    )
-
-    module.transfer_archives(
-        dry_run=False,
-        repository_path='repo',
-        config={'log_json': True},
-        local_borg_version='2.3.4',
-        transfer_arguments=flexmock(
-            archive=None,
-            progress=None,
-            match_archives=None,
-            source_repository=None,
-        ),
-        global_arguments=flexmock(),
-    )
-
-
 def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
@@ -458,7 +421,42 @@ def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--lock-wait', '5', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--lock-wait', '5', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        output_file=None,
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    )
+
+    module.transfer_archives(
+        dry_run=False,
+        repository_path='repo',
+        config=config,
+        local_borg_version='2.3.4',
+        transfer_arguments=flexmock(
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
+        ),
+        global_arguments=flexmock(),
+    )
+
+
+def test_transfer_archives_calls_borg_with_extra_borg_options():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    config = {'extra_borg_options': {'transfer': '--extra "value with space"'}}
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'transfer', '--log-json', '--extra', 'value with space', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -519,6 +517,43 @@ def test_transfer_archives_with_progress_calls_borg_with_progress_flags():
     )
 
 
+def test_transfer_archives_with_log_json_and_progress_calls_borg_with_both_flags():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags').with_args('progress', True).and_return(
+        ('--progress',),
+    )
+    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'transfer', '--log-json', '--progress', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        output_file=module.DO_NOT_CAPTURE,
+        environment=None,
+        working_directory=None,
+        borg_local_path='borg',
+        borg_exit_codes=None,
+    )
+
+    module.transfer_archives(
+        dry_run=False,
+        repository_path='repo',
+        config={'log_json': True, 'progress': True},
+        local_borg_version='2.3.4',
+        transfer_arguments=flexmock(
+            archive=None,
+            progress=None,
+            match_archives=None,
+            source_repository=None,
+        ),
+        global_arguments=flexmock(),
+    )
+
+
 @pytest.mark.parametrize('argument_name', ('upgrader', 'sort_by', 'first', 'last'))
 def test_transfer_archives_passes_through_arguments_to_borg(argument_name):
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
@@ -533,7 +568,7 @@ def test_transfer_archives_passes_through_arguments_to_borg(argument_name):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', flag_name, 'value', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', flag_name, 'value', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -570,7 +605,7 @@ def test_transfer_archives_with_source_repository_calls_borg_with_other_repo_fla
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(None)
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--repo', 'repo', '--other-repo', 'other'),
+        ('borg', 'transfer', '--log-json', '--repo', 'repo', '--other-repo', 'other'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
@@ -608,6 +643,7 @@ def test_transfer_archives_with_date_based_matching_calls_borg_with_date_based_f
         (
             'borg',
             'transfer',
+            '--log-json',
             '--newer',
             '1d',
             '--newest',
@@ -657,7 +693,7 @@ def test_transfer_archives_calls_borg_with_working_directory():
         '/working/dir',
     )
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'transfer', '--repo', 'repo'),
+        ('borg', 'transfer', '--log-json', '--repo', 'repo'),
         output_log_level=module.borgmatic.logger.ANSWER,
         output_file=None,
         environment=None,
